Class: GbData

Inherits:
Object
  • Object
show all
Includes:
Utils::Hash
Defined in:
lib/ce-greenbutton/model/gb_data.rb

Overview

Represents an IntervalBlock structure.

Author TCSASSEMBLER Version 1.0

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Utils::Hash

#to_hash

Instance Attribute Details

#gb_data_descriptionObject

A reference to the owner GbDataDescription



12
13
14
# File 'lib/ce-greenbutton/model/gb_data.rb', line 12

def gb_data_description
  @gb_data_description
end

#interval_readingsObject

An array of GbDataReading



22
23
24
# File 'lib/ce-greenbutton/model/gb_data.rb', line 22

def interval_readings
  @interval_readings
end

#time_durationObject

Represents the duration value from the IntervalBlock -> Interval structure



19
20
21
# File 'lib/ce-greenbutton/model/gb_data.rb', line 19

def time_duration
  @time_duration
end

#time_startObject

Represents the start time (local) value from the IntervalBlock -> Interval structure



16
17
18
# File 'lib/ce-greenbutton/model/gb_data.rb', line 16

def time_start
  @time_start
end

Instance Method Details

#_parseObject

Returns the parsed elements as a hash with key equals the property name and value equals the parsed value.



26
27
28
# File 'lib/ce-greenbutton/model/gb_data.rb', line 26

def _parse
  to_hash
end