Class: GbDataDescription
- Inherits:
-
Object
- Object
- GbDataDescription
- Includes:
- Utils::Hash
- Defined in:
- lib/ce-greenbutton/model/gb_data_description.rb
Overview
Represents common data for a UsagePoint
Author TCSASSEMBLER Version 1.0
Instance Attribute Summary collapse
-
#commodity ⇒ Object
Represents the commodity value of the corresponding ReadingType structure.
-
#currency ⇒ Object
Represents the currency value of the corresponding ReadingType structure.
-
#custodian ⇒ Object
Represents the custodian value in the ApplicationInformation structure.
-
#gb_data_array ⇒ Object
An array of GbData.
-
#power_of_ten_multiplier ⇒ Object
Represents the “powerOfTenMultiplier” value of the corresponding ReadingType structure.
-
#unit_of_measure ⇒ Object
Represents the “uom” value of the corresponding ReadingType structure.
-
#updated ⇒ Object
Represents the last updated date/time.
-
#user_id ⇒ Object
Represents the access_token used to retrieve the GreenButton data.
Instance Method Summary collapse
-
#_parse ⇒ Object
Returns the parsed elements as a hash with key equals the property name and value equals the parsed value.
Methods included from Utils::Hash
Instance Attribute Details
#commodity ⇒ Object
Represents the commodity value of the corresponding ReadingType structure.
18 19 20 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 18 def commodity @commodity end |
#currency ⇒ Object
Represents the currency value of the corresponding ReadingType structure.
21 22 23 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 21 def currency @currency end |
#custodian ⇒ Object
Represents the custodian value in the ApplicationInformation structure.
12 13 14 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 12 def custodian @custodian end |
#gb_data_array ⇒ Object
An array of GbData
34 35 36 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 34 def gb_data_array @gb_data_array end |
#power_of_ten_multiplier ⇒ Object
Represents the “powerOfTenMultiplier” value of the corresponding ReadingType structure.
28 29 30 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 28 def power_of_ten_multiplier @power_of_ten_multiplier end |
#unit_of_measure ⇒ Object
Represents the “uom” value of the corresponding ReadingType structure.
24 25 26 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 24 def unit_of_measure @unit_of_measure end |
#updated ⇒ Object
Represents the last updated date/time
31 32 33 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 31 def updated @updated end |
#user_id ⇒ Object
Represents the access_token used to retrieve the GreenButton data.
15 16 17 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 15 def user_id @user_id end |
Instance Method Details
#_parse ⇒ Object
Returns the parsed elements as a hash with key equals the property name and value equals the parsed value.
38 39 40 |
# File 'lib/ce-greenbutton/model/gb_data_description.rb', line 38 def _parse to_hash end |