Exception: GreenButton::InvalidGbDataError
- Inherits:
-
Exception
- Object
- Exception
- GreenButton::InvalidGbDataError
- Defined in:
- lib/ce-greenbutton.rb
Overview
Will be raised if a parsing or semantic error occurred during the data
parsing/interpretation
For example, if the data does not contain a LocalTimeParameters structure
Author: ahmed.seddiq Version: 1.0